@@ -673,7 +673,7 @@ class KeycloakAdmin:
         """
         Assign a realm role to a group
 
-        :param user_id: id of group
+        :param group_id: id of group
         :param roles: roles list or role (use RoleRepresentation)
         :return Keycloak server response
         """
@@ -684,6 +684,21 @@ class KeycloakAdmin:
                                             data=json.dumps(payload))
         return raise_error_from_response(data_raw, KeycloakGetError, expected_code=204)
 
+    def revoke_realm_group_role(self, group_id, roles):
+        """
+        Revoke a realm role to a group
+
+        :param group_id: id of group
+        :param roles: roles list or role (use RoleRepresentation)
+        :return Keycloak server response
+        """
+
+        payload = roles if isinstance(roles, list) else [roles]
+        params_path = {"realm-name": self.realm_name, "id": group_id}
+        data_raw = self.connection.raw_delete(URL_ADMIN_GROUP_REALM_ROLES.format(**params_path),
+                                            data=json.dumps(payload))
+        return raise_error_from_response(data_raw, KeycloakGetError, expected_code=204)
+
     def delete_client_group_roles(self, group_id, client_id, roles):
         """
         Delete client roles from a group.
